==> elogind-229.8.tar.gz: elogind-229.8/src/cgroups-agent/cgroups-agent.c <==
/***
  This file is part of systemd.

  Copyright 2010 Lennart Poettering

  systemd is free software; you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  systemd is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with systemd; If not, see <http://www.gnu.org/licenses/>.
***/

#include <stdlib.h>

#include "sd-bus.h"

#include "bus-util.h"
#include "log.h"

/// Additional includes needed by elogind
#include "musl_missing.h"

int main(int argc, char *argv[]) {
        _cleanup_(sd_bus_flush_close_unrefp) sd_bus *bus = NULL;
        int r;

        if (argc != 2) {
                log_error("Incorrect number of arguments.");
                return EXIT_FAILURE;
        }

#if 1 /// elogind explicitly sets program_invocation_name when needed
        elogind_set_program_name(argv[0]);
#endif // 1
        log_set_target(LOG_TARGET_AUTO);
        log_parse_environment();
        log_open();

#if 0 /// elogind does not attach to systemd
        /* We send this event to the private D-Bus socket and then the
         * system instance will forward this to the system bus. We do
         * this to avoid an activation loop when we start dbus when we
         * are called when the dbus service is shut down. */

        r = bus_connect_system_systemd(&bus);
#else
        /* Unlike in systemd where this has to use a private socket,
           since elogind doesn't associate control groups with services
           and doesn't manage the dbus service, we can just use the
           system bus.  */
        r = sd_bus_open_system(&bus);
#endif // 0
        if (r < 0) {
#if 0 /// elogind does not attach to systemd
                /* If we couldn't connect we assume this was triggered
                 * while systemd got restarted/transitioned from
                 * initrd to the system, so let's ignore this */
                log_debug_errno(r, "Failed to get D-Bus connection: %m");
#else
                /* If dbus isn't running or responding, there is nothing
                 * we can do about it. */
                log_debug_errno(r, "Failed to open system bus: %m");
#endif // 0
                return EXIT_FAILURE;
        }

        r = sd_bus_emit_signal(bus,
                               "/org/freedesktop/elogind/agent",
                               "org.freedesktop.elogind.Agent",
                               "Released",
                               "s", argv[1]);
        if (r < 0) {
#if 0 /// elogind does not attach to systemd
                log_debug_errno(r, "Failed to send signal message on private connection: %m");
#else
                log_debug_errno(r, "Failed to send signal message: %m");
#endif // 0
                return EXIT_FAILURE;
        }

        return EXIT_SUCCESS;
}

==> elogind-235.4.tar.gz: elogind-235.4/src/cgroups-agent/cgroups-agent.c <==
/***
  This file is part of systemd.

  Copyright 2010 Lennart Poettering

  systemd is free software; you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
  (at your option) any later version.

  systemd is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with systemd; If not, see <http://www.gnu.org/licenses/>.
***/

#include <stdlib.h>
#include <sys/socket.h>

#include "fd-util.h"
#include "log.h"
#include "socket-util.h"

/// Additional includes needed by elogind
#include "musl_missing.h"

int main(int argc, char *argv[]) {

        static const union sockaddr_union sa = {
                .un.sun_family = AF_UNIX,
                .un.sun_path = "/run/systemd/cgroups-agent",
        };

        _cleanup_close_ int fd = -1;
        ssize_t n;
        size_t l;

        if (argc != 2) {
                log_error("Incorrect number of arguments.");
                return EXIT_FAILURE;
        }

        elogind_set_program_name(argv[0]);
        log_set_target(LOG_TARGET_AUTO);
        log_parse_environment();
        log_open();

        fd = socket(AF_UNIX, SOCK_DGRAM|SOCK_CLOEXEC, 0);
        if (fd < 0) {
                log_debug_errno(errno, "Failed to allocate socket: %m");
                return EXIT_FAILURE;
        }

        l = strlen(argv[1]);

        n = sendto(fd, argv[1], l, 0, &sa.sa, SOCKADDR_UN_LEN(sa.un));
        if (n < 0) {
                log_debug_errno(errno, "Failed to send cgroups agent message: %m");
                return EXIT_FAILURE;
        }

        if ((size_t) n != l) {
                log_debug("Datagram size mismatch");
                return EXIT_FAILURE;
        }

        return EXIT_SUCCESS;
}
